package sun.reflect.generics.repository;

import sun.reflect.generics.tree.Tree;
import sun.reflect.generics.tree.ClassTypeSignature;
import sun.reflect.generics.visitor.Reifier;
import sun.reflect.generics.parser.SignatureParser;
import sun.reflect.generics.factory.GenericsFactory;
import java.lang.reflect.Type;
import sun.reflect.generics.tree.ClassSignature;

public class ClassRepository extends GenericDeclRepository<ClassSignature>
{
    public static final ClassRepository NONE;
    private volatile Type superclass;
    private volatile Type[] superInterfaces;
    
    private ClassRepository(String s, GenericsFactory genericsFactory) {
        super(s, genericsFactory);
    }
    
    @Override
    protected ClassSignature parse(String s) {
        return SignatureParser.make().parseClassSig(s);
    }
    
    public static ClassRepository make(String s, GenericsFactory genericsFactory) {
        return new ClassRepository(s, genericsFactory);
    }
    
    public Type getSuperclass() {
        Type superclass = this.superclass;
        if (superclass == null) {
            Reifier reifier = this.getReifier();
            ((ClassSignature)this.getTree()).getSuperclass().accept(reifier);
            superclass = reifier.getResult();
            this.superclass = superclass;
            return superclass;
        }
        return superclass;
    }
    
    public Type[] getSuperInterfaces() {
        Type[] superInterfaces = this.superInterfaces;
        if (superInterfaces == null) {
            ClassTypeSignature[] superInterfaces2 = ((ClassSignature)this.getTree()).getSuperInterfaces();
            superInterfaces = new Type[superInterfaces2.length];
            Reifier reifier;
            for (int i = 0; i < superInterfaces2.length; superInterfaces[i] = reifier.getResult(), ++i) {
                reifier = this.getReifier();
                superInterfaces2[i].accept(reifier);
            }
            this.superInterfaces = superInterfaces;
        }
        return (Type[])superInterfaces.clone();
    }
    
    static {
        NONE = make("Ljava/lang/Object;", null);
    }
}
